@@ -5,7 +5,7 @@ use warnings;
 use utf8;
 use Regexp::Grammars;
 
-our $VERSION = '0.88';
+our $VERSION = '0.93';
 
 sub new {
 	my ($class) = @_;
@@ -395,6 +395,7 @@ sub PT::BoolOperands::X {
 		|| $class->{ScalarVariable}
 		|| $class->{ArrayElement}
 		|| $class->{HashElement}
+		|| $class->{ClassAccessor}
 		|| $class->{ClassFunctionReturn}
 		|| $class->{FunctionReturn} )->X($className);
 }
@@ -1065,7 +1066,7 @@ my $parser = qr {
     <objrule:  PT::BoolExpression>             <BoolOperands> <BoolOperatorExpression>?
     <objrule:  PT::BoolOperatorExpression>     <BoolOperator> <BoolOperands>
     <objrule:  PT::BoolOperands>               <RealNumber> | <String> | <ScalarVariable> | <ArrayElement> | <HashElement>
-						| <ClassFunctionReturn> | <FunctionReturn>
+						| <ClassAccessor> | <ClassFunctionReturn> | <FunctionReturn>
     <objrule:  PT::BoolOperator>               <GreaterThan> | <LessThan> | <Equals> | <GreaterThanEquals> | <LessThanEquals>
                                                | <StringEquals> | <StringNotEquals> | <NotEqulas> | <LogicalAnd> | <LogicalOr>
     <objrule:  PT::ElsIf>                      <[ElsIfChain]>+
@@ -1195,7 +1196,7 @@ sub parse {
         my $code = $/{Lang}->X();
         return $code;
     } else {
-        my $notMatch = "print 'not valid source';";
+        my $notMatch = "print 'Error';";
 	return $notMatch;
     }
 }
@@ -1243,7 +1244,5 @@ Rajkumar Reddy
 
 Copyright (C) 2022 by Rajkumar Reddy. All rights reserved.
 
-Open Source.
-
 
 =cut
